# WARNING: This package is synced with FC

%global __requires_exclude GLIBC_PRIVATE

#one of valgrind internal library is not linked to libc. Not sure if it should be fixed or not (since all test don't pass anyway), so disable check for now
%define _disable_ld_no_undefined 1

Summary:	Dynamic analysis tools to detect memory or thread bugs and profile
Name:		valgrind
Version:	3.24.0
Release:	%mkrel 3
License:	GPLv2+
Group:		Development/Tools
URL:		https://valgrind.org/

%ifarch %{ix86} %{arm32}
%global build_openmpi 0
%else
%global build_openmpi 1
%endif

# Generating minisymtabs doesn't really work for the staticly linked
# tools. Note (below) that we don't strip the vgpreload libraries at all
# because valgrind might read and need the debuginfo in those (client)
# libraries for better error reporting and sometimes correctly unwinding.
# So those will already have their full symbol table.
%undefine _include_minidebuginfo

Source0: https://sourceware.org/pub/valgrind/valgrind-%{version}.tar.bz2

# From Fedora:

# Needs investigation and pushing upstream
Patch1: valgrind-3.9.0-cachegrind-improvements.patch

# Make ld.so supressions slightly less specific.
Patch2: valgrind-3.9.0-ldso-supp.patch

# Add some stack-protector
Patch3: valgrind-3.16.0-some-stack-protector.patch

# Add some -Wl,z,now.
Patch4: valgrind-3.16.0-some-Wl-z-now.patch

# VALGRIND_3_24_BRANCH patches
Patch5: 0001-Prepare-NEWS-for-branch-3.24-fixes.patch
Patch6: 0002-vgdb.c-fork_and_exec_valgrind-Fix-off-by-one-error-w.patch
Patch7: 0003-vgdb.c-fork_and_exec_valgrind-Fix-another-off-by-one.patch
Patch8: 0004-regtest-add-a-fdleak-filter-for-write-on-write-on-li.patch
Patch9: 0005-Add-exp-and-supp-patterns-for-missing-main-frame-for.patch
Patch10: 0006-Add-additional-exp-ppc64le-files-to-EXTRA_DIST.patch
Patch11: 0007-Add-support-for-landlock_create_ruleset-444-landlock.patch
Patch12: 0008-helgrind-tests-tc17_sembar.c-Remove-bool-typedef.patch
Patch13: 0009-drd-tests-swapcontext.c-Rename-typedef-struct-thread.patch
Patch14: 0010-none-tests-bug234814.c-sa_handler-take-an-int-as-arg.patch
Patch15: 0011-Add-open_tree-move_mount-fsopen-fsconfig-fsmount-fsp.patch

#END OF FEDORA PATCHES

Patch1000: valgrind-3.24.0-arm.patch

BuildRequires:	glibc-devel
BuildRequires:	glibc-static-devel
BuildRequires:	gdb
# (proyvind): build with support for OpenMP, boost & qt4 threads
BuildRequires:	libgomp-devel
BuildRequires:	boost-devel
Recommends:	gdb
%if %{build_openmpi}
BuildRequires: openmpi-devel
%endif

# gdbserver_tests/filter_make_empty uses ps in test
BuildRequires: procps

# Some testcases require g++ to build
BuildRequires: gcc-c++

# check_headers_and_includes uses Getopt::Long
BuildRequires: perl(Getopt::Long)

# We always autoreconf
BuildRequires: automake
BuildRequires: autoconf

# For make check validating the documentation
BuildRequires: docbook-dtds

# For running the testsuite.
# Some of the python scripts require python 3.9+
BuildRequires: python3-devel

# Define valarch, the architecture name that valgrind uses
# And only_arch, the configure option to only build for that arch.
%ifarch %{ix86}
%define valarch x86
%define only_arch --enable-only32bit
%endif

%ifarch x86_64
%define valarch amd64
%define only_arch --enable-only64bit
%endif
%ifarch armv7hl
%define valarch arm
%define only_arch --enable-only32bit
%endif
%ifarch aarch64
%define valarch arm64
%define only_arch --enable-only64bit
%endif

%description
When a program is run under Valgrind's supervision, all reads and
writes of memory are checked, and calls to malloc/new/free/delete are
intercepted. As a result, Valgrind can detect problems such as:

    * Use of uninitialised memory
    * Reading/writing memory after it has been free'd
    * Reading/writing off the end of malloc'd blocks
    * Reading/writing inappropriate areas on the stack
    * Memory leaks -- where pointers to malloc'd blocks are lost forever
    * Passing of uninitialised and/or unaddressable memory to system calls
    * Mismatched use of malloc/new/new [] vs free/delete/delete []

#--------------------------------------------------------------------

%package	devel
Summary:	Development files for valgrind
Group:		%{group}
Conflicts:	%{name} < 3.6.1-3

%description	devel
Header files and libraries for development of valgrind aware programs
or valgrind plugins.

%package tools-devel
Summary: Development files for building valgrind tools
Group: Development/Tools
Requires: valgrind-devel = %{version}-%{release}
Provides: %{name}-static = %{version}-%{release}

%description tools-devel
Header files and libraries for development of valgrind tools.

#--------------------------------------------------------------------

%if %{build_openmpi}
%package openmpi
Summary: OpenMPI support for valgrind
Group: Development/Tools
Requires: %{?scl_prefix}valgrind = %{version}-%{release}

%description openmpi
A wrapper library for debugging OpenMPI parallel programs with valgrind.
See the section on Debugging MPI Parallel Programs with Valgrind in the
Valgrind User Manual for details.
%endif
#--------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}
%patch -P1 -p1
%patch -P2 -p1
%patch -P3 -p1
%patch -P4 -p1

%patch -P5 -p1
%patch -P6 -p1
%patch -P7 -p1
%patch -P8 -p1
%patch -P9 -p1
%patch -P10 -p1
%patch -P11 -p1
%patch -P12 -p1
%patch -P13 -p1
%patch -P14 -p1
%patch -P15 -p1

%patch -P1000 -p1

%build

# Some patches (might) touch Makefile.am or configure.ac files.
# Just always autoreconf so we don't need patches to prebuild files.
./autogen.sh

# Old openmpi-devel has version depended paths for mpicc.
%if %{build_openmpi}
%define mpiccpath %{!?scl:%{_bindir}}%{?scl:%{_root_bindir}}/mpicc
%else
# We explicitly don't want the libmpi wrapper. So make sure that configure
# doesn't pick some random mpi compiler that happens to be installed.
%define mpiccpath /bin/false
%endif

# Filter out "hardening" flags that don't make sense for valgrind.
# -fstack-protector just cannot work (valgrind would have to implement
# its own version since it doesn't link with glibc and handles stack
# setup itself). We patch some flags back in just for those helper
# programs where it does make sense.
#
# -Wl,-z,now doesn't make sense for static linked tools
# and would prevent using the vgpreload libraries on binaries that
# don't link themselves against libraries (like pthread) which symbols
# are needed (but only if the inferior itself would use them).
#
# -O2 doesn't work for the vgpreload libraries either. They are meant
# to not be optimized to show precisely what happened. valgrind adds
# -O2 itself wherever suitable.
#
# On ppc64[be] -fexceptions is troublesome.
# It might cause an undefined reference to `_Unwind_Resume'
# in libcoregrind-ppc64be-linux.a(libcoregrind_ppc64be_linux_a-readelf.o):
# In function `read_elf_symtab__ppc64be_linux.
#
# Also disable strict symbol checks because the vg_preload library
# will use hidden/undefined symbols from glibc like __libc_freeres.
%undefine _strict_symbol_defs_build

%ifarch ppc64
CFLAGS="`echo " %{optflags} " | sed 's/ -fstack-protector\([-a-z]*\) / / g;s/ -O2 / /g;s/ -fexceptions / /g;'`"
%else
CFLAGS="`echo " %{optflags} " | sed 's/ -fstack-protector\([-a-z]*\) / / g;s/ -O2 / /g;'`"
%endif
export CFLAGS

# Older Fedora/RHEL only had __global_ldflags.
# Even older didn't even have that (so we don't need to scrub them).
%if 0%{?build_ldflags:1}
LDFLAGS="`echo " %{build_ldflags} "    | sed 's/ -Wl,-z,now / / g;'`"
%else
%if 0%{?__global_ldflags:1}
LDFLAGS="`echo " %{__global_ldflags} " | sed 's/ -Wl,-z,now / / g;'`"
%endif
%endif
export LDFLAGS

%configure \
  --with-mpicc=%{mpiccpath} \
  %{only_arch} \
  GDB=%{_bindir}/gdb \
  --with-gdbscripts-dir=%{_datadir}/gdb/auto-load \
  --enable-lto

%make_build

%install
# Don't strip (prevent valgrind from working properly, as explained in README_PACKAGERS)
export DONT_STRIP=1

%make_install
mkdir docs/installed
mv $RPM_BUILD_ROOT%{_datadir}/doc/valgrind/* docs/installed/
rm -f docs/installed/*.ps

# We want the MPI wrapper installed under the openmpi libdir so the script
# generating the MPI library requires picks them up and sets up the right
# openmpi libmpi.so requires. Install symlinks in the original/upstream
# location for backwards compatibility.
%if %{build_openmpi}
pushd $RPM_BUILD_ROOT%{_libdir}
mkdir -p openmpi/valgrind
cd valgrind
mv libmpiwrap-%{valarch}-linux.so ../openmpi/valgrind/
ln -s ../openmpi/valgrind/libmpiwrap-%{valarch}-linux.so
popd
%endif

# We don't want debuginfo generated for the vgpreload libraries.
# Turn off execute bit so they aren't included in the debuginfo.list.
# We'll turn the execute bit on again in %%files.
chmod 644 $RPM_BUILD_ROOT%{_libexecdir}/valgrind/vgpreload*-%{valarch}-*so

%check
%ifnarch %{arm32}
# Make sure some info about the system is in the build.log
# Add || true because rpm on copr EPEL6 acts weirdly and we don't want
# to break the build.
uname -a
rpm -q glibc gcc binutils || true
LD_SHOW_AUXV=1 /bin/true
cat /proc/cpuinfo

# Make sure a basic binary runs. There should be no errors.
./vg-in-place --error-exitcode=1 /bin/true --help

# Make sure no extra CFLAGS, CXXFLAGS or LDFLAGS leak through,
# the testsuite sets all flags necessary. See also configure above.
%make_build CFLAGS="" CXXFLAGS="" LDFLAGS="" check
# some tests are known to fail,
# just check no more tests are failing than Fedora ;)

echo ===============TESTING===================
# On arm the gdb integration tests hang for unknown reasons.
%ifarch %{arm}
  make nonexp-regtest || :
%else
  make regtest || :
%endif

# Make sure test failures show up in build.log
# Gather up the diffs (at most the first 20 lines for each one)
MAX_LINES=20
diff_files=`find gdbserver_tests */tests -name '*.diff*' | sort`
if [ z"$diff_files" = z ] ; then
   echo "Congratulations, all tests passed!" >> diffs
else
   for i in $diff_files ; do
      echo "=================================================" >> diffs
      echo $i                                                  >> diffs
      echo "=================================================" >> diffs
      if [ `wc -l < $i` -le $MAX_LINES ] ; then
         cat $i                                                >> diffs
      else
         head -n $MAX_LINES $i                                 >> diffs
         echo "<truncated beyond $MAX_LINES lines>"            >> diffs
      fi
   done
fi
cat diffs
echo ===============END TESTING===============
%endif

%files
%license COPYING COPYING.DOCS
%doc NEWS README_*
%doc FAQ.txt
%doc docs/installed/html docs/installed/*.pdf
%{_bindir}/*
%dir %{_libexecdir}/valgrind
# Install everything in the libdir except the .so.
# The vgpreload so files might need file mode adjustment.
%{_libexecdir}/valgrind/*[^o]
# Turn on executable bit again for vgpreload libraries.
# Was disabled in %%install to prevent debuginfo stripping.
%attr(0755,root,root) %{_libexecdir}/valgrind/vgpreload*-%{valarch}-*so
%{_mandir}/man1/*
%{_datadir}/gdb/auto-load/valgrind-monitor.py
%{_datadir}/gdb/auto-load/valgrind-monitor-def.py

%files devel
%dir %{_includedir}/valgrind
%{_includedir}/valgrind/valgrind.h
%{_includedir}/valgrind/cachegrind.h
%{_includedir}/valgrind/callgrind.h
%{_includedir}/valgrind/drd.h
%{_includedir}/valgrind/helgrind.h
%{_includedir}/valgrind/memcheck.h
%{_includedir}/valgrind/dhat.h
%{_libdir}/pkgconfig/valgrind.pc

%files tools-devel
%license COPYING
%{_includedir}/valgrind/config.h
%{_includedir}/valgrind/libvex*h
%{_includedir}/valgrind/pub_tool_*h
%{_includedir}/valgrind/vki
%dir %{_libdir}/valgrind
%{_libdir}/valgrind/*.a

%if %{build_openmpi}
%files openmpi
%dir %{_libdir}/valgrind
%{_libdir}/openmpi/valgrind/libmpiwrap*.so
%{_libdir}/valgrind/libmpiwrap*.so
%endif


%changelog
* Tue Jul 01 2025 umeabot <umeabot> 3.24.0-3.mga10
+ Revision: 2233567
- Mageia 10 Mass Rebuild

* Fri Jan 03 2025 daviddavid <daviddavid> 3.24.0-2.mga10
+ Revision: 2135099
- disable testsuite on arm

* Fri Jan 03 2025 daviddavid <daviddavid> 3.24.0-1.mga10
+ Revision: 2135073
- new version: 3.24.0
- fix openpmi support
- disable openmpi support on 32bit

* Sun Feb 04 2024 wally <wally> 3.22.0-2.mga10
+ Revision: 2037095
- rebuild for arm32
- update %%patch usage
- drop unneeded ExclusiveArch and old obsoletes

* Tue Jan 09 2024 daviddavid <daviddavid> 3.22.0-1.mga10
+ Revision: 2029095
- new version: 3.22.0

* Thu Dec 07 2023 wally <wally> 3.20.0-3.mga10
+ Revision: 2014424
- rebuild for arm32

* Tue Nov 22 2022 tv <tv> 3.20.0-2.mga9
+ Revision: 1910153
- Avoid using implicit int C89 feature

* Sat Nov 05 2022 tv <tv> 3.20.0-1.mga9
+ Revision: 1903699
- Upgrade to valgrind 3.20.0
- Drop old patches

* Fri May 20 2022 tv <tv> 3.19.0-2.mga9
+ Revision: 1859601
- iconv_open causes ld.so v2.28+ to execute optimised strncmp (KDE#434764)

* Tue Apr 12 2022 tv <tv> 3.19.0-1.mga9
+ Revision: 1848986
- Upgrade to valgrind 3.19.0. Drop old patches.

* Thu Mar 31 2022 umeabot <umeabot> 3.18.1-6.mga9
+ Revision: 1837388
- Mageia 9 Mass Rebuild

* Mon Feb 28 2022 tv <tv> 3.18.1-5.mga9
+ Revision: 1786668
- Demangle Rust v0 symbols with .llvm suffix (KDE#445916)
- arm64: Mismatch detected between RDMA and atomics features (KDE#449494)
- Valgrind segfault on power10 due to hwcap checking code (KDE#447995)
- s390x: Valgrind indicates illegal instruction on wflrx (KDE#447991)

* Mon Dec 13 2021 tv <tv> 3.18.1-4.mga9
+ Revision: 1761928
- Handle new Linux kernel feature: Restartable Sequences ("rseq") (KDE#405377)
- gdb_server test failures on s390x (KDE#444481)
- Inline stack frame generation is broken for Rust binaries (KDE#445668)
- Using C++ condition_variable results in bogus
  "mutex is locked simultaneously by two threads" warning (KDE#445504)
- Fix for the prefixed stq instruction in PC relative mode.
  pstq instruction for R=1 is not storing to the correct address (KDE#444836)
- gdbserver_tests: Filter out glibc hwcaps libc.so
- Rust v0 symbol demangling is broken (KDE#445184)
- arm64 backend: incorrect code emitted for doubleword CAS (KDE#445354)
- arm64: unhandled instruction LD{,A}XP and ST{,L}XP (KDE#444399)
- arm64 front end: alignment checks missing for atomic instructions. (KDE#445415)
- amd64 front end: add more spec rules
- dhat/tests/copy fails on s390x (KDE#444495)
- s390x: Sign-extend "relative long" offset in EXRL (KDE#444242)
- PPC, fix lxsibzx and lxsihzx (KDE#444571)
- Update to upstream 3.18.1 final
- Drop all upstreamed patches

* Mon Oct 18 2021 tv <tv> 3.18.1-1.mga9
+ Revision: 1752042
- Update to upstream 3.18.1 final
- Drop all upstreamed patches

* Tue Oct 12 2021 tv <tv> 3.17.0-6.mga9
+ Revision: 1750645
- Update the expected output for test_isa_3_1_VRT (KDE#441534)
- m_debuginfo: Handle DW_TAG_atomic_type
- Valgrind: very slow execution (KDE#442061)

* Thu Aug 26 2021 tv <tv> 3.17.0-5.mga9
+ Revision: 1742582
- unhandled ppc64 syscalls 252 (statfs64 and 253 (fstatfs64) (KDE#440670)
- vgdb might eat all memory while waiting for sigstop (KDE#441474)
- update test_isa_3_1_common.c to avoid modulo against hard regs (KDE#440906)
- remove troublesome block of code from guest_ppc_toIR for pstxvp (KDE#441512)

* Thu Jul 22 2021 tv <tv> 3.17.0-4.mga9
+ Revision: 1737396
- m_debuginfo/debuginfo.c VG_(get_fnname_kind) _start is below main
- missing syscall wrapper for clone3 (435, KDE#420906)

* Mon Jul 19 2021 tv <tv> 3.17.0-3.mga9
+ Revision: 1736907
- gdbserver_tests: update filters for newer glibc/gdb
- glibc-2.34 breaks suppressions against obj:*/lib*/libc-2.*so* (KDE#439590)

* Mon Jun 07 2021 tv <tv> 3.17.0-2.mga9
+ Revision: 1730084
- Don't look for separate debuginfo if image already has .debug_info (KDE#435908)
- Only process clone results in the parent thread (KDE#423963)

* Sun Mar 28 2021 tv <tv> 3.17.0-1.mga9
+ Revision: 1711291
- Update to upstream 3.17.0 final

* Wed Mar 17 2021 tv <tv> 3.17.0-0.1.RC2.mga9
+ Revision: 1704142
- Update to upstream 3.17.0-RC2

* Mon Mar 15 2021 tv <tv> 3.17.0-0.1.RC1.mga9
+ Revision: 1703396
- Update to upstream 3.17.0-RC1

* Thu Mar 04 2021 tv <tv> 3.16.1-12.mga9
+ Revision: 1697998
- arm64: Handle sp, lr, fp as DwReg in CfiExpr (KDE#433898)

* Sun Feb 28 2021 tv <tv> 3.16.1-11.mga9
+ Revision: 1693285
- shmat() calls for 32-bit programs fail when running in 64-bit (KDE#410743)
- valgrind appears to only interject readlink on /proc/self/exe (RHBZ#1925786)
- -flto makes valgrind report non-existing paths to source files (RHBZ#1927153)

* Sat Jan 30 2021 tv <tv> 3.16.1-10.mga8
+ Revision: 1674052
- # KDE#432102 Support DWARF5
- PPC_FEATURE2_SCV needs to be masked in AT_HWCAP2 (KDE#431157)

* Mon Dec 21 2020 tv <tv> 3.16.1-9.mga8
+ Revision: 1662462
- Add support for Linux FICLONE ioctl (KDE#397605)
- valgrind makes false complaint about strcmp() on aarch64 (rhbz#1909415)

* Thu Dec 17 2020 tv <tv> 3.16.1-8.mga8
+ Revision: 1660446
- expr_is_guardable doesn't handle Iex_Qop (KDE#430485)

* Tue Dec 15 2020 tv <tv> 3.16.1-7.mga8
+ Revision: 1657883
- KDE#426014 arm64: implement fmadd and fmsub as Iop_MAdd/Sub
- KDE#430354 ppc stxsibx and stxsihx instructions write too much data

* Fri Dec 04 2020 tv <tv> 3.16.1-6.mga8
+ Revision: 1652521
- KDE#428909 helgrind: need to intercept duplicate libc definitions
- KDE#428648 s390_emit_load_mem panics due to 20-bit offset for vector load
- KDE#133812 s390x: z14 vector instructions not implemented
- gdbserver_tests/nlcontrolc.vgtest sometimes hangs (KDE#427931)
- lmw, lswi and related PowerPC insns aren't allowed on ppc64le (KDE#427870)

* Sat Oct 17 2020 tv <tv> 3.16.1-4.mga8
+ Revision: 1636482
- Support new faccessat2 linux syscall (439, KDE#427787)

* Wed Aug 19 2020 tv <tv> 3.16.1-3.mga8
+ Revision: 1615502
- Fix epoll warning (https://bugs.kde.org/show_bug.cgi?id=422623
  https://bugzilla.redhat.com/show_bug.cgi?id=1844778#c10)

* Sat Aug 01 2020 tv <tv> 3.16.1-2.mga8
+ Revision: 1610225
- Add valgrind-3.16.1-REX-prefix-JMP.patch
- Add valgrind-3.16.1-epoll.patch
- Add valgrind-3.16.1-sched_getsetattr.patch
- Add valgrind-3.16.1-dl_runtime_resolve.patch

* Tue Jun 23 2020 tv <tv> 3.16.1-1.mga8
+ Revision: 1598676
- 3.16.1

* Sun May 31 2020 tv <tv> 3.16.0-2.mga8
+ Revision: 1589191
- Apply stack-protector and -Wl,z,now patches again

* Thu May 28 2020 tv <tv> 3.16.0-1.mga8
+ Revision: 1588441
- Update to upstream valgrind 3.16.0 final

* Wed May 20 2020 tv <tv> 3.16.0-0.4.RC2.mga8
+ Revision: 1586345
- libmpiwrap is no more there
- Update to upstream 3.16.0 RC2
- s390x: Add CPU model for z15

* Sun Mar 01 2020 tv <tv> 3.15.0-7.mga8
+ Revision: 1552622
- sync patches with FC

* Tue Feb 18 2020 umeabot <umeabot> 3.15.0-6.mga8
+ Revision: 1538115
- Mageia 8 Mass Rebuild

* Fri Feb 14 2020 tv <tv> 3.15.0-5.mga8
+ Revision: 1522092
- sync patches with FC
- gcc10 fixes
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 13 2019 tv <tv> 3.15.0-4.mga8
+ Revision: 1459839
- Incorrect size of struct vki_siginfo on 64-bit Linux architectures (KDE#405201)

* Thu Aug 29 2019 tv <tv> 3.15.0-3.mga8
+ Revision: 1435027
- sync patches with FC

* Mon Jul 01 2019 tv <tv> 3.15.0-2.mga8
+ Revision: 1416626
- sync patches with FC

* Mon Apr 22 2019 tv <tv> 3.15.0-1.mga7
+ Revision: 1394728
- valgrind-3.15.0 final
- Drop close_fds, it is no longer needed.

* Fri Apr 12 2019 tv <tv> 3.15.0-0.1.RC2.mga7
+ Revision: 1389357
- Update to 3.15.0.RC2.
- Drop upstreamed patches

* Wed Apr 10 2019 tv <tv> 3.15.0-0.1.RC1.mga7
+ Revision: 1387987
- Update to upstream 3.15.0-RC1

* Wed Mar 06 2019 tv <tv> 3.14.0-5.mga7
+ Revision: 1371822
- sync patches with FC
- sync patches with FC

* Wed Jan 16 2019 tv <tv> 3.14.0-4.mga7
+ Revision: 1357435
- sync patches with FC
- Update valgrind-3.14.0-jm-vmx-constraints.patch for ppc64.
- Show all diff files in check, not just the main/default one.

* Mon Dec 17 2018 tv <tv> 3.14.0-3.mga7
+ Revision: 1342254
- sync patches with FC

* Sun Dec 02 2018 tv <tv> 3.14.0-2.mga7
+ Revision: 1337374
- sync patches with FC

* Sat Oct 13 2018 tv <tv> 3.14.0-1.mga7
+ Revision: 1319936
- 3.14.0 final

* Thu Oct 04 2018 tv <tv> 3.14.0-0.1RC2.mga7
+ Revision: 1317553
- Upgrade to RC2

* Thu Sep 20 2018 tv <tv> 3.14.0-0.1GIT.mga7
+ Revision: 1279588
- New upstream (pre-)release (mga#23397)
- Add valgrind-3.14.0-add-vector-h.patch

* Fri Sep 14 2018 tv <tv> 3.13.0-16.mga7
+ Revision: 1258947
- utimensat should ignore tv_sec for UTIME_NOW or UTIME_OMIT (KDE#397354)

* Fri Aug 10 2018 tv <tv> 3.13.0-15.mga7
+ Revision: 1250938
- sync patches with RH

* Wed Jun 20 2018 tv <tv> 3.13.0-14.mga7
+ Revision: 1238319
- Improved valgrind-3.13.0-arm64-hwcap.patch
- Add valgrind-3.13.0-arm64-ptrace.patch

* Wed May 09 2018 tv <tv> 3.13.0-13.mga7
+ Revision: 1227857
- Add valgrind-3.13.0-build-id-phdrs.patch (rhbz#1566639)
- Add valgrind-3.13.0-ppc64-mtfprwa-constraint.patch.

* Mon Mar 12 2018 tv <tv> 3.13.0-12.mga7
+ Revision: 1208615
- Split valgrind-tools-devel from valgrind-devel.
  (thus fixing gnome-build's build)
- use newer macros

* Sun Jan 07 2018 tv <tv> 3.13.0-10.mga7
+ Revision: 1191352
- sync patches with FC

* Sat Dec 30 2017 cjw <cjw> 3.13.0-9.mga7
+ Revision: 1187930
- fix build for arm
- add patch19 from fedora

* Tue Dec 12 2017 tv <tv> 3.13.0-8.mga7
+ Revision: 1182434
- Fix gnu debug alt file resolving

* Wed Oct 18 2017 tv <tv> 3.13.0-7.mga7
+ Revision: 1172612
- new release
- fix source URL
- sync patches with RH
- fix handling command line option --xml-socket

* Thu Jul 20 2017 tv <tv> 3.12.0-6.mga7
+ Revision: 1125666
- sync patches with FC

* Sat Jun 24 2017 luigiwalser <luigiwalser> 3.12.0-5.mga6
+ Revision: 1108344
- add patch from ubuntu to fix CVE-2016-4491 (mga#21126)

* Tue Dec 06 2016 tv <tv> 3.12.0-4.mga6
+ Revision: 1072737
- fix testsuite (rhbz#1390282)
- replace most of armv5 patch by a simple sed command

* Tue Oct 25 2016 tv <tv> 3.12.0-3.mga6
+ Revision: 1063479
- rediff armv5 "patch"

* Tue Oct 25 2016 tv <tv> 3.12.0-2.mga6
+ Revision: 1063469
- patch 1000: try to fix linking on arm

* Tue Oct 25 2016 tv <tv> 3.12.0-1.mga6
+ Revision: 1063449
- final release

* Fri Oct 21 2016 tv <tv> 3.12.0-0.1.RC2.mga6
+ Revision: 1062884
- 3.12.0.RC2

* Thu Jul 28 2016 tv <tv> 3.11.0-14.mga6
+ Revision: 1043819
- fix devel pkg summary
- sync patches with FC
- apply patches like FC does

* Thu Jun 30 2016 tv <tv> 3.11.0-13.mga6
+ Revision: 1038188
- sync patches with FC

* Mon May 09 2016 tv <tv> 3.11.0-12.mga6
+ Revision: 1011787
- sync patches with FC
- sync patches with FC

* Fri Apr 22 2016 tv <tv> 3.11.0-11.mga6
+ Revision: 1004923
- sync patches with FC

* Wed Apr 13 2016 tv <tv> 3.11.0-10.mga6
+ Revision: 1001076
- sync patches with FC
- switch to %%autopatch

* Sun Mar 06 2016 tv <tv> 3.11.0-9.mga6
+ Revision: 986854
- further adjust file list
- try to fix openmpi support
- further adjust file list (openmpi support seems broken?)
- adjust file list
- fix chmod
- move a lib in openmpi subpackage
- move a lib in openmpi subpackage
- move a lib in openmpi subpackage
- move *.a in devel package
- sync patches with RH

* Thu Jan 21 2016 tv <tv> 3.11.0-6.mga6
+ Revision: 926191
- sync patches with RH

* Sun Jan 17 2016 tv <tv> 3.11.0-5.mga6
+ Revision: 924821
- sync patches with FC
- notice that this package is synced with FC
+ pterjan <pterjan>
- Fix arm patch

* Sun Nov 29 2015 tv <tv> 3.11.0-4.mga6
+ Revision: 907211
- sync patches with FC

* Sun Nov 22 2015 pterjan <pterjan> 3.11.0-3.mga6
+ Revision: 904917
- Make it build on armv5tl

* Wed Sep 30 2015 tv <tv> 3.11.0-2.mga6
+ Revision: 885246
- rebuild for new libmpi

* Thu Sep 24 2015 tv <tv> 3.11.0-1.mga6
+ Revision: 883298
- fix doc packaging
- try to fix debuginfo
- new release

* Fri Jul 24 2015 tv <tv> 3.10.1-4.mga6
+ Revision: 857020
- sync patches with FC

* Sun Jun 28 2015 tv <tv> 3.10.1-3.mga6
+ Revision: 846670
- fix mismerge
- sync patches with FC (kernel-4+ support)

* Fri Feb 20 2015 tv <tv> 3.10.1-2.mga5
+ Revision: 816078
- sync patches with FC

* Sat Jan 24 2015 tv <tv> 3.10.1-1.mga5
+ Revision: 812110
- new version
- sync patches with FC

* Wed Oct 22 2014 tv <tv> 3.10.0-3.mga5
+ Revision: 792474
- sync patches with FC

* Wed Oct 15 2014 umeabot <umeabot> 3.10.0-2.mga5
+ Revision: 743654
- Second Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Fri Sep 12 2014 tv <tv> 3.10.0-1.mga5
+ Revision: 674779
- 3.10.0 final

* Wed Sep 10 2014 tv <tv> 3.10.0-0.2.BETA2.mga5
+ Revision: 674502
- handle glibc-2.20

* Tue Sep 09 2014 tv <tv> 3.10.0-0.1.BETA2.mga5
+ Revision: 674079
- 3.10.0 BETA2
- don't run dwz or generate minisymtab
  (instead of disabling the whole debuginfo package)

* Wed Sep 03 2014 tv <tv> 3.10.0-0.1.BETA1.mga5
+ Revision: 671350
- 3.10.0 BETA1
- enables inlined frames in stacktraces

* Mon Sep 01 2014 luigiwalser <luigiwalser> 3.9.0-9.svn20140829r14384.mga5
+ Revision: 670358
- remove epoch from requires for valgrind-openmpi

* Sun Aug 31 2014 tv <tv> 3.9.0-8.svn20140829r14384.mga5
+ Revision: 669841
- fix group
- enable openmpi support

* Fri Aug 29 2014 tv <tv> 3.9.0-7.svn20140829r14384.mga5
+ Revision: 669299
- update to upstream svn r14384

* Wed Aug 27 2014 tv <tv> 3.9.0-7.svn20140827r14371.mga5
+ Revision: 668833
- update to upstream svn r14370

* Wed Aug 27 2014 tv <tv> 3.9.0-7.svn20140809r14250.mga5
+ Revision: 668592
- fix default suppresions file location

* Tue Aug 12 2014 tv <tv> 3.9.0-6.svn20140809r14250.mga5
+ Revision: 661862
- new release

* Sat Aug 02 2014 tv <tv> 3.9.0-6.svn20140718r14176.mga5
+ Revision: 659299
- new snapshot
- sync patches with RH

* Fri Feb 28 2014 tv <tv> 3.9.0-6.mga5
+ Revision: 597955
- sync patches with RH:
  o Add upstream fixes to valgrind-3.9.0-timer_create.patch
  o Add valgrind-3.9.0-glibc-2.19.patch
  o Add valgrind-3.9.0-s390-dup3.patch
  o Add valgrind-3.9.0-timer_create.patch

* Mon Feb 17 2014 tmb <tmb> 3.9.0-5.mga5
+ Revision: 593950
- rebuild with new glibc

* Sun Feb 09 2014 pterjan <pterjan> 3.9.0-3.mga5
+ Revision: 587806
- Fix spec
+ tv <tv>
- sync patches with RH

* Sun Feb 09 2014 tmb <tmb> 3.9.0-2.mga5
+ Revision: 587781
- support glibc 2.19 (P7, Arch)
- rebuild for new glibc

* Tue Nov 05 2013 tv <tv> 3.9.0-1.mga4
+ Revision: 549603
- new release 3.9.0
- package NEWS
- kill patches that are now upstream
- sync patches with FC

* Mon Oct 21 2013 umeabot <umeabot> 3.8.1-14.mga4
+ Revision: 539058
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 tv <tv> 3.8.1-13.mga4
+ Revision: 491272
- sync with FC:
  o rename patch 50 a 52
  o filter out -mcpu= so tests are compiled with the right flags (rhbz#996927)
  o implement SSE4 MOVNTDQA insn
  o fix power_ISA2_05 testcase
  o fix ppc32 make check build
  o add valgrind-3.8.1-mmxext.patch

* Fri Oct 04 2013 shlomif <shlomif> 3.8.1-12.mga4
+ Revision: 491263
- Get rid of trailing whitespace in the spec
- Fix for RH#1011713. Broke some tests.

* Wed Aug 21 2013 tv <tv> 3.8.1-11.mga4
+ Revision: 469105
- Allow building against glibc 2.18 (rhbz#999169)

* Wed Aug 21 2013 tv <tv> 3.8.1-10.mga4
+ Revision: 468611
- sync patches with FC

* Mon Jul 15 2013 tv <tv> 3.8.1-9.mga4
+ Revision: 454891
- sync patches with RH

* Mon Jul 08 2013 fwang <fwang> 3.8.1-8.mga4
+ Revision: 451225
- rebuild for new boost
+ tv <tv>
- sync patches with FC

* Mon May 27 2013 tv <tv> 3.8.1-7.mga4
+ Revision: 428964
- sync patches with FC

* Mon Jan 14 2013 umeabot <umeabot> 3.8.1-6.mga3
+ Revision: 385224
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 cjw <cjw> 3.8.1-5.mga3
+ Revision: 339934
- patch103: allow to build with glibc 2.17

* Fri Dec 14 2012 tv <tv> 3.8.1-4.mga3
+ Revision: 330586
- rebuild for new gdb

* Sun Nov 18 2012 tv <tv> 3.8.1-3.mga3
+ Revision: 319493
- sync patches with FC (after fixing them trying to patch .orig files...)
+ malo <malo>
- update RPM group

* Thu Oct 11 2012 tv <tv> 3.8.1-2.mga3
+ Revision: 304680
- sync patches with FC

* Wed Sep 26 2012 tv <tv> 3.8.1-1.mga3
+ Revision: 297921
- new release
- sync with FC patches

* Mon Aug 27 2012 tv <tv> 3.8.0-4.mga3
+ Revision: 284624
- new release

* Tue Aug 21 2012 tv <tv> 3.8.0-3.mga3
+ Revision: 282942
- patch 100: fix a crash with mini debug info

* Mon Aug 20 2012 blino <blino> 3.8.0-2.mga3
+ Revision: 282510
- add valgrind-3.8.0-find-buildid.patch workaround from Fedora (RH#849435 KDE#305431)

* Mon Aug 13 2012 tv <tv> 3.8.0-1.mga3
+ Revision: 281166
- drop patch  (what comment said was merged)
- drop merged glibc-2.16 patch
- drop now useless automake patch
- drop merged FC patches
- add new patches from FC
- add one patch from FC (on i?86 prefer to use CFI over %%ebp unwinding, as GCC
  4.6+ defaults to -fomit-frame-pointer)
- like FC, filter out some compilation flags (getting rid of new cloberring
  issues due to -fPIC on x86_64)
- fix install

* Sat Aug 11 2012 blino <blino> 3.7.0-5.mga3
+ Revision: 280480
- add patches from Fedora (and upstream valgrind) to handle dwz DWARF compressor output

* Wed Jul 25 2012 shlomif <shlomif> 3.7.0-4.mga3
+ Revision: 274227
- Convert paths to /usr/lib* instead of /lib* in the suppressions.
  This is another fallout of the /usr-move.

* Sat Jul 21 2012 shlomif <shlomif> 3.7.0-3.mga3
+ Revision: 273153
- Add a blurb to the patch
- New release for glibc-2.16.x.
  1. Fix build with new automake.
  2. Update the valgrind package to accept building against 2.16 (with a patch
  derived from the svn).
  3. Fix problems with unpacked files.
  4. Put a symlink to a place that valgrind is looking for.

* Wed Dec 21 2011 shlomif <shlomif> 3.7.0-1.mga2
+ Revision: 185524
- Cancel make regtest because it hangs.
+ fwang <fwang>
- sync with mandriva package

* Thu Oct 27 2011 shlomif <shlomif> 3.6.1-5.mga2
+ Revision: 158760
- Applied patches to build against kernel-3.x and glibc-2.14.x

* Wed Jun 22 2011 ahmad <ahmad> 3.6.1-4.mga2
+ Revision: 111971
- Add conflicts to ease updates after the -devel split (from tv)
- Re-enable building with qt4
- Only run autoreconf when building with qt4
- Drop unapplied patch3

* Tue Jun 07 2011 dmorgan <dmorgan> 3.6.1-3.mga2
+ Revision: 101519
- Provide devel subpackage  ( partial merge of mdv commit 659516)

* Sun May 15 2011 pterjan <pterjan> 3.6.1-2.mga1
+ Revision: 99037
- Rebuild for fixed find-requires

* Sat Apr 16 2011 pterjan <pterjan> 3.6.1-1.mga1
+ Revision: 86603
- Update to 3.6.1

* Tue Jan 11 2011 blino <blino> 3.6.0-2.mga1
+ Revision: 6503
- do not build with qt4 support for now
- remove versions in comments
- imported package valgrind


* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 3.6.0-1mdv2011.0
+ Revision: 593038
- Update to valgrind 3.6.0

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - build with support for OpenMP, boost & qt4 threads

* Mon Dec 07 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.5.0-2mdv2010.1
+ Revision: 474521
- Correct valgrind to work with glibc-2.11.

* Wed Aug 26 2009 Eugeni Dodonov <eugeni@mandriva.com> 3.5.0-1mdv2010.0
+ Revision: 421314
- updated to 3.5.0

* Thu Jun 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.4.1-3mdv2010.0
+ Revision: 389173
- add wildcards after GLIBC_VERSION to match any library micro versions as well (P4 from Fedora)
- redirect x86_64 ld.so strlen early (P3, RH bug #495645)

* Tue Jun 02 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.4.1-2mdv2010.0
+ Revision: 382232
- Rebuild with newer glibc (#51374).

* Thu Mar 05 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.1-1mdv2009.1
+ Revision: 348875
- Release 3.4.1
- Regenerate patch0
- Remove patch1 (merged upstream)

* Thu Jan 15 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.0-1mdv2009.1
+ Revision: 329847
- Release 3.4.0
- Remove patches 3, 8 (merged upstream)
- Regenerate patches 0 & 1

* Mon Jun 30 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-2mdv2009.0
+ Revision: 230240
- Update patch8 with upstream fix

* Thu Jun 26 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-1mdv2009.0
+ Revision: 229225
- Release 3.3.1
- Remove patches 4, 5, 6, 7 (merged upstream)
- Don't regenerate debug package, all debug info should stay in valgrind binaries

* Fri May 30 2008 Paulo Andrade <pcpa@mandriva.com.br> 3.3.0-5mdv2009.0
+ Revision: 213483
- Don't supress warnings only if the binary has been explicitly linked
  with libraries at /usr/X11*/lib*.

  + Frederic Crozat <fcrozat@mandriva.com>
    - Rebuild with glibc 4.3 / glibc 2.8
    - run make test in check section
    - Patch0 (Fedora): add cachegrind improvement
    - Patch1 (Fedora): fix pkgconfig file (RH bug #213149)
    - Patch2 (Fedora): fix openat handling (RH bug #208097)
    - Patch3 (Fedora): suppress pthread_barrier_wait in helgrind
    - Patch4 (Fedora): add suppression for glibc 2.7
    - Patch5 (Fedora): add support for glibc 2.8
    - Patches6, 7 (Fedora): add more syscalls
    - Patch8: fix malloc_free_fill test when glibc >= 2.7

* Thu Feb 21 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-3mdv2008.1
+ Revision: 173469
- suggests gdb (#37755)

* Thu Feb 14 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-2mdv2008.1
+ Revision: 167680
- new license policy
- drop bogus doc install hacks
- buildrequires gdb (#37739)
- spec clean
- drop Source1 (it's not actually used)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Dec 18 2007 trem <trem@mandriva.org> 3.3.0-1mdv2008.1
+ Revision: 131903
- update to 3.3.0
- remove patch for glibc-2.6

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 06 2007 Olivier Blin <oblin@mandriva.com> 3.2.3-2mdv2008.0
+ Revision: 59231
- use generic man page extension in files list (for lzma)
- add glibc-2.6 support (patch from Gentoo)


* Fri Mar 16 2007 Laurent Montel <lmontel@mandriva.com> 3.2.3-1mdv2007.1
+ Revision: 144737
- 3.2.3

* Sat Jan 13 2007 Michael Scherer <misc@mandriva.org> 3.2.1-1mdv2007.1
+ Revision: 108323
- update to 3.2.1, fix illegal instruction on current libstdc++ on x86_64
- Import valgrind

* Sat Jun 17 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-2mdv2007.0
- obsoletes valgrind-plugins

* Wed Jun 14 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-1mdv2007.0
- new version
- rpmbuildupdate aware
- spec cleanup
- move doc file in doc directory

* Sat Apr 29 2006 Jerome Soyer <saispo@mandriva.org> 3.1.1-1mdk
- New release 3.1.1

* Fri Feb 17 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.1.0-2mdk
- enable build for ppc

* Thu Dec 01 2005 Laurent MONTEL <lmontel@mandriva.com> 3.1.0-1mdk
- 3.1.0

* Tue Sep 06 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.0.1-1mdk
- 3.0.1

* Fri Aug 05 2005 Laurent MONTEL <lmontel@mandriva.com> 3.0.0-1mdk
- 3.0.0

* Thu Mar 24 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.4.0-1mdk
- 2.4.0

* Wed Jan 19 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-2mdk
- Remove calltree from this package create new package valgrind-plugins and put callgrind into (because we can't compile callgrind without valgrind)

* Sat Sep 04 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-1mdk
- 2.2.0

* Thu Jul 22 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.2-1mdk
- 2.1.2 (see http://developer.kde.org/~sewardj/docs-2.0.0/NEWS.txt)

* Fri Apr 23 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-3mdk
- Add calltree plugins for kcachegrind (kdesdk)

* Tue Apr 20 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.1.1-2mdk
- fix buildrequires
- use %%configure macro
- update url
- drop patches that wasn't applied

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-1mdk
- new version

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.0-3mdk
- Don't package twice manual.html bug #9314

